@@ -97,6 +97,17 @@ module MCollective
             end
           else
             begin
+              # Identify and tokenize regular expressions by ignoring everything between /'s
+              if @arguments[j] == '/'
+                current_token_value << '/'
+                j+=1
+                while(j < @arguments.size && @arguments[j] != '/')
+                  current_token_value << @arguments[j]
+                  j += 1
+                end
+                current_token_value << @arguments[j] if @arguments[j]
+                break
+              end
               if @arguments[j+1] == "("
                 func = true
                 be_greedy = true
@@ -112,6 +123,9 @@ module MCollective
               else
                 j += 1
               end
+              if(@arguments[j] == ' ')
+                break if(is_klass?(j) && !(@arguments[j-1] =~ /=|<|>/))
+              end
               if( (@arguments[j] == ' ') && (@seperation_counter < 2) && !(current_token_value.match(/^.+(=|<|>).+$/)) )
                 if((index = lookahead(j)))
                   j = index
@@ -156,6 +170,19 @@ module MCollective
         end
       end
 
+      # Deal with special puppet class statement
+      def is_klass?(j)
+        while(j < @arguments.size && @arguments[j] == ' ')
+          j += 1
+        end
+
+        if @arguments[j] =~ /=|<|>/
+          return false
+        else
+          return true
+        end
+      end
+
       # Eat spaces while looking for the next comparison symbol
       def lookahead(index)
         index += 1
