@@ -207,8 +207,8 @@ module MCollective
 
             host[:host] = get_option("activemq.pool.#{poolnum}.host")
             host[:port] = get_option("activemq.pool.#{poolnum}.port", 61613).to_i
-            host[:login] = get_env_or_option("STOMP_USER", "activemq.pool.#{poolnum}.user")
-            host[:passcode] = get_env_or_option("STOMP_PASSWORD", "activemq.pool.#{poolnum}.password")
+            host[:login] = get_env_or_option("STOMP_USER", "activemq.pool.#{poolnum}.user", '')
+            host[:passcode] = get_env_or_option("STOMP_PASSWORD", "activemq.pool.#{poolnum}.password", '')
             host[:ssl] = get_bool_option("activemq.pool.#{poolnum}.ssl", "false")
 
             # if ssl is enabled set :ssl to the hash of parameters
@@ -424,7 +424,7 @@ module MCollective
         Log.error("Received subscription request for #{source.inspect.chomp} but already had a matching subscription, ignoring")
       end
 
-      # Subscribe to a topic or queue
+      # UnSubscribe to a topic or queue
       def unsubscribe(agent, type, collective)
         source = make_target(agent, type, collective)
 
@@ -486,7 +486,7 @@ module MCollective
 
         case type
           when :reply
-            target[:name] = ["/queue/" + collective, :reply, "#{Config.instance.identity}_#{$$}"].join(".")
+            target[:name] = ["/queue/" + collective, :reply, "#{Config.instance.identity}_#{$$}", Client.request_sequence].join(".")
 
           when :broadcast
             target[:name] = ["/topic/" + collective, agent, :agent].join(".")
