@@ -102,8 +102,8 @@ module MCollective
 
             host[:host] = get_option("rabbitmq.pool.#{poolnum}.host")
             host[:port] = get_option("rabbitmq.pool.#{poolnum}.port", 61613).to_i
-            host[:login] = get_env_or_option("STOMP_USER", "rabbitmq.pool.#{poolnum}.user")
-            host[:passcode] = get_env_or_option("STOMP_PASSWORD", "rabbitmq.pool.#{poolnum}.password")
+            host[:login] = get_env_or_option("STOMP_USER", "rabbitmq.pool.#{poolnum}.user", '')
+            host[:passcode] = get_env_or_option("STOMP_PASSWORD", "rabbitmq.pool.#{poolnum}.password", '')
             host[:ssl] = get_bool_option("rabbitmq.pool.#{poolnum}.ssl", "false")
 
             # if ssl is enabled set :ssl to the hash of parameters
@@ -332,8 +332,10 @@ module MCollective
 
         target = {:name => "", :headers => {}, :id => nil}
 
-        if get_bool_option("rabbitmq.use_reply_exchange", false)
-          reply_path = "/exchange/mcollective_reply/%s_%s" % [ @config.identity, $$ ]
+        if reply_to
+          reply_path = reply_to
+        elsif get_bool_option("rabbitmq.use_reply_exchange", false)
+          reply_path = "/exchange/mcollective_reply/%s_%s_%s" % [ @config.identity, $$, Client.request_sequence ]
         else
           reply_path = "/temp-queue/mcollective_reply_%s" % agent
         end
